"""
Tests for carta_envoy.carta
"""
import argparse
from pathlib import Path
from unittest.mock import patch

# pylint: disable=C0116, E0401, R0201, W0613

from carta_envoy import carta

expected_settings = {
    "timeout": "1",
    "carta_path": "/fake/path/to/nowhere",
    "redis_host": "noplace.nrao.edu",
    "redis_port": "6397",
    "redis_password": "password",
    "reverse_proxy": "black-abyss.nrao.edu",
    "data_location": Path("/fake/location/path"),
    "useCarta": "False",
    "notification_url": "http://notification:3458",
    "workflow_url": "http://workflow:3456",
    "single_image": False,
    "ui_url": "http://localhost:4444/workspaces",
}

LOCATION = "/fake/location/path"


class TestCarta:
    """Tests for carta module"""
    def test_get_settings(self):
        settings = carta.get_carta_settings(LOCATION)
        for key in settings.keys():
            assert settings[key] == expected_settings[key]

    def test_ensure_non_relative_path(self):
        path = carta.ensure_non_relative_path(LOCATION)
        assert path == expected_settings["data_location"]

    @patch("os.chdir")
    @patch("glob.glob")
    def test_ensure_correct_directory(self, mock_glob, mock_chdir):
        carta.ensure_correct_directory(settings=expected_settings)
        assert mock_glob.call_count == 2

    def test_make_arg_parser(self):
        assert isinstance(carta.make_arg_parser(), argparse.ArgumentParser)
